package com.sun.corba.se.spi.orb;

import java.util.Iterator;
import java.util.AbstractSet;
import java.util.Set;
import java.util.AbstractMap;
import java.util.Map;

public abstract class ParserImplTableBase extends ParserImplBase
{
    private final ParserData[] entries;
    
    public ParserImplTableBase(ParserData[] entries) {
        this.entries = entries;
        this.setDefaultValues();
    }
    
    @Override
    protected PropertyParser makeParser() {
        PropertyParser propertyParser = new PropertyParser();
        for (int i = 0; i < this.entries.length; ++i) {
            this.entries[i].addToParser(propertyParser);
        }
        return propertyParser;
    }
    
    protected void setDefaultValues() {
        this.setFields(new ParserImplTableBase.FieldMap(this.entries, true));
    }
    
    public void setTestValues() {
        this.setFields(new ParserImplTableBase.FieldMap(this.entries, false));
    }
    
    private static final class MapEntry implements Map.Entry
    {
        private Object key;
        private Object value;
        
        public MapEntry(Object key) {
            this.key = key;
        }
        
        @Override
        public Object getKey() {
            return this.key;
        }
        
        @Override
        public Object getValue() {
            return this.value;
        }
        
        @Override
        public Object setValue(Object value) {
            Object value2 = this.value;
            this.value = value;
            return value2;
        }
        
        @Override
        public boolean equals(Object o) {
            if (!(o instanceof ParserImplTableBase.MapEntry)) {
                return false;
            }
            ParserImplTableBase.MapEntry mapEntry = (ParserImplTableBase.MapEntry)o;
            return this.key.equals(mapEntry.key) && this.value.equals(mapEntry.value);
        }
        
        @Override
        public int hashCode() {
            return this.key.hashCode() ^ this.value.hashCode();
        }
    }
    
    private static class FieldMap extends AbstractMap
    {
        private final ParserData[] entries;
        private final boolean useDefault;
        
        public FieldMap(ParserData[] entries, boolean useDefault) {
            this.entries = entries;
            this.useDefault = useDefault;
        }
        
        @Override
        public Set entrySet() {
            return new AbstractSet() {
                @Override
                public Iterator iterator() {
                    return new Iterator() {
                        int ctr = 0;
                        
                        @Override
                        public boolean hasNext() {
                            return this.ctr < ParserImplTableBase.FieldMap.this.entries.length;
                        }
                        
                        @Override
                        public Object next() {
                            ParserData parserData = ParserImplTableBase.FieldMap.this.entries[this.ctr++];
                            ParserImplTableBase.MapEntry mapEntry = new ParserImplTableBase.MapEntry(parserData.getFieldName());
                            if (ParserImplTableBase.FieldMap.this.useDefault) {
                                mapEntry.setValue(parserData.getDefaultValue());
                                return mapEntry;
                            }
                            mapEntry.setValue(parserData.getTestValue());
                            return mapEntry;
                        }
                        
                        @Override
                        public void remove() {
                            throw new UnsupportedOperationException();
                        }
                    };
                }
                
                @Override
                public int size() {
                    return ParserImplTableBase.FieldMap.this.entries.length;
                }
            };
        }
    }
}
